@@ -91,7 +91,7 @@ GET_DATA = {
             "connect-timeout": {
                 "type": "int",
                 "help": ""
-            }
+            },
         }
     },
 }
@@ -99,7 +99,8 @@ GET_DATA = {
 GET_VARIABLE = {
     'provider': 'aws',
     'output': 'json',
-    'api_versions': {}
+    'api_versions': {},
+    'cli_binary_format': 'raw-in-base64-out',
 }
 
 
@@ -231,6 +232,9 @@ class FakeSession(object):
             return GET_VARIABLE[name]
         return self.session_vars[name]
 
+    def get_scoped_config(self):
+        return GET_VARIABLE
+
     def get_service_model(self, name, api_version=None):
         return botocore.model.ServiceModel(
             MINI_SERVICE, service_name='s3')
@@ -539,6 +543,7 @@ class TestAWSCommand(BaseAWSCommandParamsTest):
             param=mock.ANY,
             service_name='ec2',
             value='file:///foo',
+            parsed_globals=mock.ANY,
         )
         # Make sure it was called with our passed-in URI
         self.assertEqual(
@@ -568,6 +573,7 @@ class TestAWSCommand(BaseAWSCommandParamsTest):
             param=mock.ANY,
             service_name='custom',
             value='file:///foo',
+            parsed_globals=mock.ANY,
         )
 
     def test_custom_arg_no_paramfile(self):
